var indexSectionsWithContent =
{
  0: "_abcdefghijklmnopqrstuvw~",
  1: "_abcdefghijklmnopqrstv",
  2: "o",
  3: "abcdhjlmnoqrst",
  4: "_abcdefghiklmnopqrstuvw~",
  5: "_fhimpsuv",
  6: "cefghiknpqrstuv",
  7: "acfst",
  8: "bcdefhilmnpstuv",
  9: "ci",
  10: "defhov",
  11: "imp",
  12: "acdefhmnorstuvw"
};

var indexSectionNames =
{
  0: "all",
  1: "classes",
  2: "namespaces",
  3: "files",
  4: "functions",
  5: "variables",
  6: "typedefs",
  7: "enums",
  8: "enumvalues",
  9: "related",
  10: "defines",
  11: "groups",
  12: "pages"
};

var indexSectionLabels =
{
  0: "All",
  1: "Classes",
  2: "Namespaces",
  3: "Files",
  4: "Functions",
  5: "Variables",
  6: "Typedefs",
  7: "Enumerations",
  8: "Enumerator",
  9: "Friends",
  10: "Macros",
  11: "Modules",
  12: "Pages"
};

